Changelog
=========

Unreleased_
-----------
No changes committed.

0.1.4_ (2019-09-01)
-------------------
Features:

- Migreated project to Visual Studio 2019 / 2017.  Fixes #8.

0.1.3_ (2018-06-09)
-------------------
Bug Fixes:

- Fixed escape sequence in environment interpolation. Fixes #7.

0.1.2_ (2018-05-31)
-------------------
Features:

- Added support for PTVS project environment variables. Fixes #5.

Compatibility Notes:

- Dropped Python 3.3 support. Fixes #6.

0.1.1_ (2017-09-07)
-------------------
Bug Fixes:

- Fixed exception with corrupt interpreters and/or environment; Fixes #4.

Features:

- Replaced raw file writer with jinja2 renderer. Fixes #1.

0.1.0 (2017-03-18)
------------------
- Initial Split from `VSGen 0.3.0`_.

.. _0.1.4: https://github.com/dbarsam/python-vsgen-ptvs/compare/0.1.3...0.1.4
.. _0.1.3: https://github.com/dbarsam/python-vsgen-ptvs/compare/0.1.2...0.1.3
.. _0.1.2: https://github.com/dbarsam/python-vsgen-ptvs/compare/0.1.1...0.1.2
.. _0.1.1: https://github.com/dbarsam/python-vsgen-ptvs/compare/0.1.0...0.1.1
.. _unreleased: https://github.com/dbarsam/python-vsgen-ptvs/compare/0.1.3...HEAD
.. _VSGen 0.3.0: https://github.com/dbarsam/python-vsgen/releases/tag/0.3.0
